==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/SaveAbility.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveAbility] (
	@Instance Varchar(50) = NULL, 				
	@ID Varchar(50) = NULL,
	@Title Varchar(100) = NULL,					
	@Detail Varchar(500) = NULL,
	@Type VARCHAR(25) = NULL,
	@Binary Bit = NULL,
	@NotApply Bit = NULL,
	@AcceptComments Bit = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Enabled bit = NULL,
	@Query VarChar(1000) = NULL,
	@QueryName VarChar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [Ability]
	SET [Title] = @Title,
		[Detail] = @Detail,
		[Type] = @Type,
		[Binary] = @Binary,
		[NotApply] = @NotApply, [AcceptComments] = @AcceptComments,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
		[TimeStamp] = GETUTCDATE(),
		[Query] = @Query,
		[QueryName] = @QueryName
	WHERE [Instance] = @Instance
    AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [Ability] (
			[Instance], [ID],
			[Title], [Detail], 
			[Type], [Binary],
			[NotApply], [AcceptComments],
			[CreatedDate],
			[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
			[Enabled], [TimeStamp], [Query], [QueryName]
			)
		VALUES (
			@Instance, @ID,
			@Title, @Detail, 
			@Type, @Binary,
			@NotApply, @AcceptComments,
			@CreatedDate,
			@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
			1, GETUTCDATE(), @Query, @QueryName
		)

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.15.1_database.tar.gz: database/mssql/procedures/SaveAbility.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveAbility] (
	@Instance Varchar(50) = NULL, 				
	@ID Varchar(50) = NULL,
	@Title Varchar(100) = NULL,					
	@Detail Varchar(500) = NULL,
	@Type VARCHAR(25) = NULL,
	@Binary Bit = NULL,
	@NotApply Bit = NULL,
	@AcceptComments Bit = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Enabled bit = NULL,
	@AnalysisType VARCHAR(25) = NULL,
	@Language VARCHAR(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [Ability]
	SET [Title] = @Title,
		[Detail] = @Detail,
		[Type] = @Type,
		[Binary] = @Binary,
		[NotApply] = @NotApply, [AcceptComments] = @AcceptComments,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[Enabled] = CASE WHEN @Enabled IS NULL THEN 1 ELSE @Enabled END,
		[TimeStamp] = GETUTCDATE(),
		[AnalysisType] = @AnalysisType,
		[Language] = @Language
	WHERE [Instance] = @Instance
    AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [Ability] (
			[Instance], [ID],
			[Title], [Detail], 
			[Type], [Binary],
			[NotApply], [AcceptComments],
			[CreatedDate],
			[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId],
			[Enabled], [TimeStamp], 
			[AnalysisType], [Language]
			)
		VALUES (
			@Instance, @ID,
			@Title, @Detail, 
			@Type, @Binary,
			@NotApply, @AcceptComments,
			@CreatedDate,
			@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId,
			1, GETUTCDATE(), 
			@AnalysisType, @Language
		)

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
